# spheres
toolbox for higher spin and symmetrization

[![Documentation Status](https://readthedocs.org/projects/spheres/badge/?version=latest)](https://spheres.readthedocs.io/en/latest/?badge=latest)

[![PyPI version](https://badge.fury.io/py/spheres.svg)](https://badge.fury.io/py/spheres)

[![Travis CI](https://travis-ci.com/heyredhat/spheres.svg?branch=main)](https://travis-ci.com/github/heyredhat/spheres)

[![codecov](https://codecov.io/gh/heyredhat/spheres/branch/main/graph/badge.svg?token=980CL7KIFL)](https://codecov.io/gh/heyredhat/spheres)

[![Updates](https://pyup.io/repos/github/heyredhat/spheres/shield.svg)](https://pyup.io/repos/github/heyredhat/spheres/)

[![Python 3](https://pyup.io/repos/github/heyredhat/spheres/python-3-shield.svg)](https://pyup.io/repos/github/heyredhat/spheres/)
